Constants
Functions
- cs_
slot_ status - Get the chip-select slot status for debugging purposes.
- delay_
slot_ status - Get the delay slot status for debugging purposes.
- register
- Register a serial port at the specified slot index.
- register_
cs - Register a chip-select output pin implementing embedded-hal 1.0
OutputPin. - register_
delay - Register a delay provider implementing embedded-hal 1.0
DelayNs. - register_
spi - Register an SPI bus that implements embedded-hal 1.0
SpiBus. - slot_
status - Get the serial slot status for debugging purposes.
- spi_
slot_ status - Get the SPI slot status for debugging purposes.
- take
- Take (consume) a serial port from the specified slot index.
- take_cs
- Consume a chip-select output pin from the specified slot index.
- take_
delay - Consume a delay provider from the specified slot index.
- take_
spi - Consume an SPI bus from the specified slot index.